AudioPlayback class abstract
Minimal playback surface used by AudioService.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Releases playback resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
play(
) → Future< void> - Starts playback.
-
setAsset(
String filePath) → Future< void> - Loads an asset for playback.
-
setLoopMode(
LoopMode loopMode) → Future< void> - Sets the looping behavior.
-
stop(
) → Future< void> - Stops playback.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited