setMuteState method

void setMuteState(
  1. bool muted
)

Sets the microphone mute state to a specific value.

@param muted True to mute the microphone, false to unmute.

Implementation

void setMuteState(bool muted) {
  peerConnection?.setMuteState(muted);
}