getLastHeldCall method
Returns the last held call, or null if there are no held calls.
Implementation
Call? getLastHeldCall() {
return _heldCalls.isNotEmpty ? _heldCalls.last : null;
}
Returns the last held call, or null if there are no held calls.
Call? getLastHeldCall() {
return _heldCalls.isNotEmpty ? _heldCalls.last : null;
}