setCurrentCall method

void setCurrentCall(
  1. Call? call
)

Sets call as the current active call.

If call is currently in heldCalls it will be removed from there first. If there was a previous currentCall it is not automatically put on hold – the caller is responsible for managing that transition (see holdCurrentAndAcceptIncoming).

Implementation

void setCurrentCall(Call? call) {
  if (call != null) {
    _heldCalls.removeWhere((c) => c.callId == call.callId);
  }

  _currentCall = call;
  _currentCallController.add(call);
  _notifyHeldCallsChanged();
}