JustAudioPlayback class
just_audio-backed playback adapter.
- Implemented types
Constructors
- JustAudioPlayback({AudioPlayer? audioPlayer})
- Creates a playback adapter.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
Releases playback resources.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
play(
) → Future< void> -
Starts playback.
override
-
setAsset(
String filePath) → Future< void> -
Loads an asset for playback.
override
-
setLoopMode(
LoopMode loopMode) → Future< void> -
Sets the looping behavior.
override
-
stop(
) → Future< void> -
Stops playback.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited