onIncomingCallRejected method

void onIncomingCallRejected(
  1. String callId
)

Rejects an incoming call by sending BYE with USER_BUSY cause.

This is a no-op on the CallManager state if the call was not the current call (which it shouldn't be – it's ringing). The actual BYE sending is done by rejectCall on the Call object itself.

Implementation

void onIncomingCallRejected(String callId) {
  // A rejected incoming call was never the current call, so we only need to
  // ensure it's removed from the general tracking (if it was somehow
  // registered).
  unregisterCall(callId);
}