DefaultConfig class
Default configuration values for Telnyx WebRTC connections.
This class provides constants for production and development server addresses, as well as default ICE server configurations for TURN/STUN.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
defaultDevIceServers
→ List<
TxIceServer> -
Default development ICE servers configuration.
no setter
-
defaultProdIceServers
→ List<
TxIceServer> -
Default production ICE servers configuration.
no setter
Constants
- defaultStun → const String
- Production STUN server
- defaultTurn → const String
- Production TURN server with TCP transport
- defaultTurnUdp → const String
- Production TURN server with UDP transport (preferred for lower latency)
- devStun → const String
- Development STUN server
- devTurn → const String
- Development TURN server with TCP transport
- devTurnUdp → const String
- Development TURN server with UDP transport
- googleStun → const String
- Google's public STUN server for additional reliability
- password → const String
- socketHostAddress → const String
- telnyxDevHostAddress → const String
- telnyxPort → const int
- telnyxProdHostAddress → const String
- username → const String